Group

Struct Group 

pub struct Group<D, I>
where D: Delimiter, I: Parse,
{ /* private fields */ }
A Group represents a delimited item. Group has two Generic types:

  • D is the delimiter tokens around the item, it has to a type that implements tokens::Delimiter.
  • I is the type of item inside the delimiters, it has to implement Parse.
    let buffer = "(\"Hello, World\")".to_owned();
    let mut buffer = CharStream::new(buffer).build();

    let value = Group::<tokens::Paren, StringValue>::parse(&mut buffer);
    assert!(value.is_ok());

    let buffer = "[0, 1, 2]".to_owned();
    let mut buffer = CharStream::new(buffer).build();

    let value = Group::<tokens::Bracket, List<Number, tokens::Comma>>::parse(&mut buffer);
    assert!(value.is_ok());